==> kf5-messagelib_17.12.3.orig.tar.xz: messagelib-17.12.3/messageviewer/src/viewer/csshelper.h <==
/*  -*- c++ -*-
    csshelper.h

    This file is part of KMail, the KDE mail client.
    Copyright (c) 2003 Marc Mutz <mutz@kde.org>

    KMail is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License, version 2, as
    published by the Free Software Foundation.

    KMail is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __MESSAGEVIEWER_CSSHELPER_H__
#define __MESSAGEVIEWER_CSSHELPER_H__

#include <MessageViewer/CSSHelperBase>

#include "messageviewer_export.h"

namespace MessageViewer {
class MESSAGEVIEWER_EXPORT CSSHelper : public CSSHelperBase
{
public:
    explicit CSSHelper(const QPaintDevice *pd);
    virtual ~CSSHelper();

    /** @return HTML head including style sheet definitions and the
    &gt;body&lt; tag */
    QString htmlHead(bool fixedFont = false) const override;
};
}

#endif // __MESSAGEVIEWER_CSSHELPER_H__

==> kf5-messagelib_19.12.3.orig.tar.xz: messagelib-19.12.3/messageviewer/src/viewer/csshelper.h <==
/*  -*- c++ -*-
    csshelper.h

    This file is part of KMail, the KDE mail client.
    Copyright (c) 2003 Marc Mutz <mutz@kde.org>

    KMail is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    KMail is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef MESSAGEVIEWER_CSSHELPER_H
#define MESSAGEVIEWER_CSSHELPER_H

#include <MessageViewer/CSSHelperBase>

#include "messageviewer_export.h"

namespace MessageViewer {
/**
 * @brief The CSSHelper class
 */
class MESSAGEVIEWER_EXPORT CSSHelper : public CSSHelperBase
{
public:
    explicit CSSHelper(const QPaintDevice *pd);
    ~CSSHelper() override;

    /** @return HTML head including style sheet definitions and the
    &gt;body&lt; tag */
    Q_REQUIRED_RESULT QString htmlHead(bool fixedFont = false) const override;
};
}

#endif // MESSAGEVIEWER_CSSHELPER_H
